"""Storage of the xpath, class and id identifiers"""

from easydict import EasyDict

markers = EasyDict(
    {
        "ChatGPT": {
            "login_xq"      : "//button[//*[text()='Log in']]",
            "email_xq"     : "//input[contains(@class, 'email-input') or @id='username']",
            "pwd_iq"        : "password",
            "continue_xq"   : "//button[text()='Continue']",
            "tutorial_xq"   : "//div[contains(text(), 'Okay, let’s go')]",
            "button_tq"     : "button",
            "done_xq"       : "//button[//div[text()='Done']]",
            "menu_xq"       : "//button[@data-testid='profile-button']",
            "custom_xq"     : "//div[contains(text(), 'Custom')]",
            "cust_toggle_xq": "//button[@role='switch']",
            "cust_txt_xq"   : "//textarea[@type='button']",
            "cust_save_xq"  : "//div[contains(text(), 'Save')]",
            "cust_cancel_xq": "//div[contains(text(), 'Cancel')]",
            "cust_tut_xq"   : "//div[text()='OK']",
            "chatbox_xq"    : "//div[@data-message-author-role='assistant']",
            "wait_xq"       : "//button[contains(@data-testid, 'stop-button')]",
            "reset_xq"      : "//a[//span[text()='New chat']]",
            "reset_cq"      : "truncate",
            "regen_xq"      : "//div[contains(@class, 'flex items-center')]//button",
            "textarea_tq"   : "textarea",
            "send_btn_xq"   : "//button[@data-testid='send-button']",
            "textarea_iq"   : "prompt-textarea",
            "gpt_xq"        : "//span[text()='{}']"
        },
        "Claude": {
            "file_types"    : [
                "pdf", "doc", "docx", "rtf", "epub", "odt", "odp", "pptx",
                "txt", "py", "ipynb", "js", "jsx", "html", "css", "java",
                "cs", "php", "c", "cpp", "cxx", "h", "hpp", "rs", "R",
                "Rmd", "swift", "go", "rb", "kt", "kts", "ts", "tsx",
                "m", "scala", "rs", "dart", "lua", "pl", "pm", "t",
                "sh", "bash", "zsh", "csv", "log", "ini", "config",
                "json", "yaml", "yml", "toml", "lua", "sql", "bat",
                "md", "coffee", "tex", "latex", "jpg", "jpeg",
                "png", "gif", "webp"
            ],
            "start_btn_xq"  : '//div[text()="Start Chat"]',
            "textarea_cq"   : "ProseMirror",
            "send_button_xq": '//button[@aria-label="Send Message"]',
            "chatarea_xq"   : '//div[contains(@class, "grid-cols-1")]/div[@class="contents"]',
            "regen_xq"      : "//button[text()='Retry']",
        },
        "Copilot": {
            "file_types"    : ["gif", "jpg", "jpeg", "png", "webp"],
            "main_area_tq"  : "cib-serp",
            "act_bar_iq"    : "cib-action-bar-main",
            "input_bar_cq"  : "input-row",
            "textarea_iq"   : "searchbox",
            "button_cq"     : "submit",
            "con_main_iq"   : "cib-conversation-main",
            "con_chat_sq"   : "cib-chat-turn",
            "con_resp_cq"   : "response-message-group",
            "con_msg_sq"    : "cib-message",
            "con_ins_sq"    : "cib-shared",
            "con_last_cq"   : "ac-textBlock",
            "ref_cq"        : "tooltip-target",
            "welcome_tq"    : "cib-welcome-container",
            "tone_tq"       : "cib-tone-selector",
            "side_tq"       : "cib-side-panel",
            "side_btns_cq"  : "pivot",
            "plugin_tq"     : "cib-plugin-panel",
            "p_control_cq"  : "plugin-control",
            "new_chat_cq"   : "button-compose-content",
            "img_upload_iq" : "vs_fileinput",
            "vis_srch_cq"   : "visual-search",
            "cam_btn_iq"    : "camera-container",
            "url_iq"        : "sb_imgpst",
            "at_list_cq"    : "cib-attachment-list",
            "file_item_cq"  : "cib-file-item",
            "thumbnail_cq"  : "thumbnail",
            "dismiss_cq"    : "dismiss"
        },
        "Gemini": {
            "file_types"    : ["jpg", "jpeg", "png", "webp"],
            "textarea_xq"   : '//div[@role="textbox"]',
            # "wait_xq"       : '//img[contains(@src, "sparkle_processing")]',
            "wait_xq"       : '//rect',
            # "wait_xq"       : '//mat-icon[@data-mat-icon-name="send"]',
            "chatbox_tq"    : "message-content",
            "new_chat_xq"   : '//expandable-button[contains(@aria-label, "New chat")]',
            "hist_off_xq"   : '//button[@data-test-id="bard-activity-disabled-button"]',
            "chat_conf_xq"  : '//button[@data-test-id="confirm-button"]',
            "regen_1_xq"    : "//span[@class='generate-drafts-button']",
            "regen_2_cq"    : "regenerate-button",
            "modify_xq"     : "//button[@aria-label='Modify response']",
            "mod_opt_xq"    : "//button[@role='menuitem'][not(contains(@style, 'none'))]",
            "img_upload_xq" : "//input[@name='Filedata']",
            # "img_btn_xq"    : "//mat-icon[contains(text(), 'add_photo_alternate')]",
            "img_btn_xq"    : "//mat-icon[@data-mat-icon-name='add_photo_alternate']",
            # "send_btn_xq"   : "//button[@aria-label='Send message']",
            "img_loaded_xq" : "//img[@aria-label='Image preview']",
            "got_it_xq"     : "//button[@data-test-id='got-it-button']"
        },
        "LeChat" : {
            "username_xq"   : "//div[@data-testid='node/input/identifier']//input",
            "password_xq"   : "//div[@data-testid='node/input/password']//input",
            "textarea_xq"   : "//div/textarea",
            "stop_gen_xq"   : "//button[@aria-label='Stop generation']",
            "chatbox_xq"    : "//*[contains(@class,'prose')]",
            "regen_xq"      : "//button[@aria-label='Rewrite']",
            "model_xq"      : "//button/span[@class='truncate']",
            "model_op_xq"   : "//div[contains(@class, 'w-full')]/div[contains(@class, 'text-sm')]"
        },
        "HuggingChat": {
            "login_xq"      : "//form[@action='/chat/login']",
            "username_xq"   : "//input[@name='username']",
            "password_xq"   : "//input[@name='password']",
            "a_login_xq"    : "//button[contains(text(), 'Login')]",
            "textarea_xq"   : "//textarea[@enterkeyhint='send']",
            "stop_gen_xq"   : "//button[contains(text(),'Stop generating')]",
            "chatbox_xq"    : "//div[@role='presentation']",
            "search_xq"     : "//div[@aria-label='web search toggle']",
            "model_xq"      : "//div[div/div/text()='Current Model']//a",
            "settings_xq"   : "//h2[text()='Settings']",
            "model_li_xq"   : "//div/a/div[@class='truncate']",
            "model_a_xq"    : "//div[h2/text()='Settings']//button",
            "model_act_xq"  : "//button[@name='Activate model']"
        },
        "Pi": {
            "textarea_xq"   : "//textarea[@role='textbox']",
            "sendkeys_xq"   : "//button[@aria-label='Submit text']",
            "wait_xq"       : "//button[@disabled]",
            "chatbox_xq"    : "//div[@class='flex items-center']",
            "model_1_xq"    : "//div[contains(@class, 'shadow-input')]//button",
            "model_2_xq"    : "//button[contains(@class, 't-body-s')]",
            "model_v_xq"    : "//div[contains(text(), 'Switched to')]"
        }
    }
)
